/* Developed for Lenovo Educational Board Pass 2
   © Lenovo Created by Joshua Grosser
   v. 1.0 */

#include <Wire.h>   // I2C library
#include "ens210.h" // ENS210 library
#include <SparkFun_APDS9960.h> // ambient light library
#include <SSD1306Wire.h> // OLED display library

// declare/initialze objects and variables
SSD1306Wire display(0x3c);
SparkFun_APDS9960 apds = SparkFun_APDS9960();
ENS210 ens210;
#define WIRE Wire
uint16_t ambient_light = 0;

void setup() {
  // Enable serial
  Serial.begin(9600);
  // initialize objects
  Wire.begin();
  ens210.begin();
  apds.init();
  apds.enableLightSensor(false);
  display.init();
  display.setContrast(255);
}

void loop() {
  // creates variables for temperature, humidity, and ambient light and measures new values
  int t_data, t_status, h_data, h_status;
  ens210.measure(&t_data, &t_status, &h_data, &h_status); 
  apds.readAmbientLight(ambient_light);
  // prints output to OLED display
  display.setLogBuffer(5, 30);
  display.clear();
  display.print("T: ");
  display.print(ens210.toFahrenheit(t_data, 10) / 10.0);
  display.print("F , H: ");
  display.print(ens210.toPercentageH(h_data,1));
  display.println("%");
  display.print("Ambient Light: ");
  display.println(ambient_light);
  display.drawLogBuffer(0, 0);
  display.display();
  delay(2);
}
